@@ -12,9 +12,9 @@ import (
 	"github.com/spf13/cobra"
 	"gopkg.in/yaml.v2"
 
-	cli "github.com/lxc/incus/v6/internal/cmd"
 	"github.com/lxc/incus/v6/internal/i18n"
 	"github.com/lxc/incus/v6/shared/api"
+	cli "github.com/lxc/incus/v6/shared/cmd"
 	"github.com/lxc/incus/v6/shared/termios"
 )
 
@@ -25,7 +25,7 @@ type cmdNetworkIntegration struct {
 // Command returns a cobra command for inclusion.
 func (c *cmdNetworkIntegration) Command() *cobra.Command {
 	cmd := &cobra.Command{}
-	cmd.Use = usage("integration")
+	cmd.Use = cli.Usage("integration")
 	cmd.Short = i18n.G("Manage network integrations")
 	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G(
 		`Manage network integrations`))
@@ -82,7 +82,7 @@ type cmdNetworkIntegrationCreate struct {
 // Command returns a cobra command for inclusion.
 func (c *cmdNetworkIntegrationCreate) Command() *cobra.Command {
 	cmd := &cobra.Command{}
-	cmd.Use = usage("create", i18n.G("[<remote>:]<network integration> <type>"))
+	cmd.Use = cli.Usage("create", i18n.G("[<remote>:]<network integration> <type>"))
 	cmd.Aliases = []string{"add"}
 	cmd.Short = i18n.G("Create network integrations")
 	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G(
@@ -175,7 +175,7 @@ type cmdNetworkIntegrationDelete struct {
 // Command returns a cobra command for inclusion.
 func (c *cmdNetworkIntegrationDelete) Command() *cobra.Command {
 	cmd := &cobra.Command{}
-	cmd.Use = usage("delete", i18n.G("[<remote>:]<network integration>"))
+	cmd.Use = cli.Usage("delete", i18n.G("[<remote>:]<network integration>"))
 	cmd.Aliases = []string{"rm", "remove"}
 	cmd.Short = i18n.G("Delete network integrations")
 	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G(
@@ -228,7 +228,7 @@ type cmdNetworkIntegrationEdit struct {
 // Command returns a cobra command for inclusion.
 func (c *cmdNetworkIntegrationEdit) Command() *cobra.Command {
 	cmd := &cobra.Command{}
-	cmd.Use = usage("edit", i18n.G("[<remote>:]<network integration>"))
+	cmd.Use = cli.Usage("edit", i18n.G("[<remote>:]<network integration>"))
 	cmd.Short = i18n.G("Edit network integration configurations as YAML")
 	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G(
 		`Edit network integration configurations as YAML`))
@@ -297,7 +297,7 @@ func (c *cmdNetworkIntegrationEdit) Run(cmd *cobra.Command, args []string) error
 	}
 
 	// Spawn the editor
-	content, err := textEditor("", []byte(c.helpTemplate()+"\n\n"+string(data)))
+	content, err := cli.TextEditor("", []byte(c.helpTemplate()+"\n\n"+string(data)))
 	if err != nil {
 		return err
 	}
@@ -320,7 +320,7 @@ func (c *cmdNetworkIntegrationEdit) Run(cmd *cobra.Command, args []string) error
 				return err
 			}
 
-			content, err = textEditor("", content)
+			content, err = cli.TextEditor("", content)
 			if err != nil {
 				return err
 			}
@@ -350,7 +350,7 @@ type networkIntegrationColumn struct {
 // Command returns a cobra command for inclusion.
 func (c *cmdNetworkIntegrationGet) Command() *cobra.Command {
 	cmd := &cobra.Command{}
-	cmd.Use = usage("get", i18n.G("[<remote>:]<network integration> <key>"))
+	cmd.Use = cli.Usage("get", i18n.G("[<remote>:]<network integration> <key>"))
 	cmd.Short = i18n.G("Get values for network integration configuration keys")
 	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G(
 		`Get values for network integration configuration keys`))
@@ -413,7 +413,7 @@ type cmdNetworkIntegrationList struct {
 // Command returns a cobra command for inclusion.
 func (c *cmdNetworkIntegrationList) Command() *cobra.Command {
 	cmd := &cobra.Command{}
-	cmd.Use = usage("list", i18n.G("[<remote>:]"))
+	cmd.Use = cli.Usage("list", i18n.G("[<remote>:]"))
 	cmd.Aliases = []string{"ls"}
 	cmd.Short = i18n.G("List network integrations")
 	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G(
@@ -437,7 +437,7 @@ Pre-defined column shorthand chars:
 	t - Type
 	u - Used by`))
 
-	cmd.Flags().StringVarP(&c.flagFormat, "format", "f", c.global.defaultListFormat(), i18n.G(`Format (csv|json|table|yaml|compact), use suffix ",noheader" to disable headers and ",header" to enable it if missing, e.g. csv,header`)+"``")
+	cmd.Flags().StringVarP(&c.flagFormat, "format", "f", c.global.defaultListFormat(), i18n.G(`Format (csv|json|table|yaml|compact|markdown), use suffix ",noheader" to disable headers and ",header" to enable it if missing, e.g. csv,header`)+"``")
 	cmd.Flags().StringVarP(&c.flagColumns, "columns", "c", defaultNetworkIntegrationColumns, i18n.G("Columns")+"``")
 
 	cmd.PreRunE = func(cmd *cobra.Command, _ []string) error {
@@ -560,7 +560,7 @@ type cmdNetworkIntegrationRename struct {
 // Command returns a cobra command for inclusion.
 func (c *cmdNetworkIntegrationRename) Command() *cobra.Command {
 	cmd := &cobra.Command{}
-	cmd.Use = usage("rename", i18n.G("[<remote>:]<network integration> <new-name>"))
+	cmd.Use = cli.Usage("rename", i18n.G("[<remote>:]<network integration> <new-name>"))
 	cmd.Aliases = []string{"mv"}
 	cmd.Short = i18n.G("Rename network integrations")
 	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G(
@@ -615,7 +615,7 @@ type cmdNetworkIntegrationSet struct {
 // Command returns a cobra command for inclusion.
 func (c *cmdNetworkIntegrationSet) Command() *cobra.Command {
 	cmd := &cobra.Command{}
-	cmd.Use = usage("set", i18n.G("[<remote>:]<network integration> <key>=<value>..."))
+	cmd.Use = cli.Usage("set", i18n.G("[<remote>:]<network integration> <key>=<value>..."))
 	cmd.Short = i18n.G("Set network integration configuration keys")
 	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G(
 		`Set network integration configuration keys
@@ -694,7 +694,7 @@ type cmdNetworkIntegrationUnset struct {
 // Command returns a cobra command for inclusion.
 func (c *cmdNetworkIntegrationUnset) Command() *cobra.Command {
 	cmd := &cobra.Command{}
-	cmd.Use = usage("unset", i18n.G("[<remote>:]<network integration> <key>"))
+	cmd.Use = cli.Usage("unset", i18n.G("[<remote>:]<network integration> <key>"))
 	cmd.Short = i18n.G("Unset network integration configuration keys")
 	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G(
 		`Unset network integration configuration keys`))
@@ -727,7 +727,7 @@ type cmdNetworkIntegrationShow struct {
 // Command returns a cobra command for inclusion.
 func (c *cmdNetworkIntegrationShow) Command() *cobra.Command {
 	cmd := &cobra.Command{}
-	cmd.Use = usage("show", i18n.G("[<remote>:]<network integration>"))
+	cmd.Use = cli.Usage("show", i18n.G("[<remote>:]<network integration>"))
 	cmd.Short = i18n.G("Show network integration options")
 	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G(
 		`Show network integration options`))
