@@ -33,12 +33,12 @@ import (
 	"github.com/lxc/incus/v6/internal/server/locking"
 	"github.com/lxc/incus/v6/internal/server/operations"
 	"github.com/lxc/incus/v6/internal/server/project"
-	"github.com/lxc/incus/v6/internal/server/resources"
 	"github.com/lxc/incus/v6/internal/server/state"
 	storagePools "github.com/lxc/incus/v6/internal/server/storage"
 	internalUtil "github.com/lxc/incus/v6/internal/util"
 	"github.com/lxc/incus/v6/shared/api"
 	"github.com/lxc/incus/v6/shared/logger"
+	"github.com/lxc/incus/v6/shared/resources"
 	"github.com/lxc/incus/v6/shared/revert"
 	"github.com/lxc/incus/v6/shared/subprocess"
 	"github.com/lxc/incus/v6/shared/util"
@@ -311,6 +311,16 @@ func (d *common) DeferTemplateApply(trigger instance.TemplateTrigger) error {
 	return nil
 }
 
+// MACPattern computes the most specific MAC address pattern for this instance.
+func (d *common) MACPattern() string {
+	macPattern, ok := d.project.Config["network.hwaddr_pattern"]
+	if !ok {
+		return d.state.GlobalConfig.NetworkHWAddrPattern()
+	}
+
+	return macPattern
+}
+
 // SetOperation sets the current operation.
 func (d *common) SetOperation(op *operations.Operation) {
 	d.op = op
@@ -794,6 +804,7 @@ func (d *common) snapshotCommon(inst instance.Instance, name string, expiry time
 		Project:      inst.Project().Name,
 		Architecture: inst.Architecture(),
 		Config:       inst.LocalConfig(),
+		Description:  inst.Description(),
 		Type:         inst.Type(),
 		Snapshot:     true,
 		Devices:      inst.LocalDevices(),
@@ -856,8 +867,7 @@ func (d *common) updateProgress(progress string) {
 	}
 
 	if meta["container_progress"] != progress {
-		meta["container_progress"] = progress
-		_ = d.op.UpdateMetadata(meta)
+		_ = d.op.ExtendMetadata(map[string]any{"container_progress": progress})
 	}
 }
 
@@ -1691,3 +1701,28 @@ func (d *common) ClearLimitsCPUNodes(changedConfig []string) {
 
 	d.localConfig["volatile.cpu.nodes"] = ""
 }
+
+// setOOMPriority applies the OOM score adjustment to the instance.
+func (d *common) setOOMPriority(pid int) error {
+	oomPriority := d.expandedConfig["limits.memory.oom_priority"]
+
+	score := int64(0)
+	var err error
+	if oomPriority != "" {
+		score, err = strconv.ParseInt(oomPriority, 10, 64)
+		if err != nil {
+			return fmt.Errorf("Invalid OOM priority value %q: %w", oomPriority, err)
+		}
+	}
+
+	if pid <= 0 {
+		return fmt.Errorf("Failed to set OOM priority: instance not running or PID not found")
+	}
+
+	err = os.WriteFile(fmt.Sprintf("/proc/%d/oom_score_adj", pid), []byte(fmt.Sprintf("%d", score)), 0o644)
+	if err != nil {
+		return fmt.Errorf("Failed to set OOM priority: %w", err)
+	}
+
+	return nil
+}
