@@ -6,8 +6,8 @@ import (
 	"strings"
 
 	"github.com/lxc/incus/v6/internal/server/instance/drivers/cfg"
-	"github.com/lxc/incus/v6/internal/server/resources"
 	"github.com/lxc/incus/v6/shared/osarch"
+	"github.com/lxc/incus/v6/shared/resources"
 )
 
 func writeHeader(sb *strings.Builder, comment string, name string) {
@@ -928,9 +928,29 @@ func qemuUSB(opts *qemuUSBOpts) []cfg.Section {
 	return sections
 }
 
+func qemuAudio(opts *qemuDevOpts) []cfg.Section {
+	entries := qemuDeviceEntries(&qemuDevEntriesOpts{
+		dev:     *opts,
+		pciName: "virtio-sound-pci",
+	})
+
+	entries["audiodev"] = "qemu_spice-audiodev"
+	return []cfg.Section{{
+		Name:    `audiodev "qemu_spice-audiodev"`,
+		Comment: "Sound device",
+		Entries: map[string]string{
+			"driver": "spice",
+		},
+	}, {
+		Name:    `device "qemu_spice-audio"`,
+		Entries: entries,
+	}}
+}
+
 type qemuTPMOpts struct {
 	devName string
 	path    string
+	driver  string
 }
 
 func qemuTPM(opts *qemuTPMOpts) []cfg.Section {
@@ -952,7 +972,7 @@ func qemuTPM(opts *qemuTPMOpts) []cfg.Section {
 	}, {
 		Name: fmt.Sprintf(`device "%s%s"`, qemuDeviceIDPrefix, opts.devName),
 		Entries: map[string]string{
-			"driver": "tpm-crb",
+			"driver": opts.driver,
 			"tpmdev": tpmdev,
 		},
 	}}
