@@ -30,7 +30,6 @@ import (
 	"github.com/lxc/incus/v6/internal/server/instance/instancetype"
 	"github.com/lxc/incus/v6/internal/server/instance/operationlock"
 	"github.com/lxc/incus/v6/internal/server/operations"
-	"github.com/lxc/incus/v6/internal/server/resources"
 	"github.com/lxc/incus/v6/internal/server/seccomp"
 	"github.com/lxc/incus/v6/internal/server/state"
 	storageDrivers "github.com/lxc/incus/v6/internal/server/storage/drivers"
@@ -42,6 +41,7 @@ import (
 	"github.com/lxc/incus/v6/shared/idmap"
 	"github.com/lxc/incus/v6/shared/logger"
 	"github.com/lxc/incus/v6/shared/osarch"
+	"github.com/lxc/incus/v6/shared/resources"
 	"github.com/lxc/incus/v6/shared/revert"
 	"github.com/lxc/incus/v6/shared/units"
 	"github.com/lxc/incus/v6/shared/util"
@@ -95,6 +95,11 @@ func ValidConfig(sysOS *sys.OS, config map[string]string, expanded bool, instanc
 		if err != nil {
 			return err
 		}
+
+		after, ok := strings.CutPrefix(k, "systemd.credential.")
+		if ok && config["systemd.credential-binary."+after] != "" {
+			return fmt.Errorf("Mutually exclusive keys %s and systemd.credential-binary.%s are set", k, after)
+		}
 	}
 
 	_, rawSeccomp := config["raw.seccomp"]
@@ -431,11 +436,11 @@ func LoadFromBackup(s *state.State, projectName string, instancePath string, app
 }
 
 // DeviceNextInterfaceHWAddr generates a random MAC address.
-func DeviceNextInterfaceHWAddr() (string, error) {
-	// Generate a new random MAC address using the usual prefix
+func DeviceNextInterfaceHWAddr(pattern string) (string, error) {
+	// Generate a new random MAC address using the given pattern.
 	ret := bytes.Buffer{}
-	for _, c := range "10:66:6a:xx:xx:xx" {
-		if c == 'x' {
+	for _, c := range pattern {
+		if c == 'x' || c == 'X' {
 			c, err := rand.Int(rand.Reader, big.NewInt(16))
 			if err != nil {
 				return "", err
@@ -1224,6 +1229,7 @@ func SnapshotProtobufToInstanceArgs(s *state.State, inst Instance, snap *migrati
 	args := db.InstanceArgs{
 		Architecture: int(snap.GetArchitecture()),
 		Config:       config,
+		Description:  inst.Description(),
 		Type:         inst.Type(),
 		Snapshot:     true,
 		Devices:      devices,
