@@ -493,6 +493,19 @@ var APIExtensions = []string{
 	"limits_memory_hotplug",
 	"disk_wwn",
 	"server_logging_webhook",
+	"storage_driver_truenas",
+	"container_disk_tmpfs",
+	"instance_limits_oom",
+	"backup_override_config",
+	"network_ovn_tunnels",
+	"init_preseed_cluster_groups",
+	"usb_attached",
+	"backup_iso",
+	"instance_systemd_credentials",
+	"cluster_group_usedby",
+	"bpf_token_delegation",
+	"file_storage_volume",
+	"network_hwaddr_pattern",
 }
 
 // APIExtensionsCount returns the number of available API extensions.
